# Changelog

## 0.1.0-alpha.6 (2024-12-02)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/justement-api/justement-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** manual updates ([#23](https://github.com/justement-api/justement-python/issues/23)) ([7afd51d](https://github.com/justement-api/justement-python/commit/7afd51d3bc776d86cd44d6f33563bebb9e1a8dfa))

## 0.1.0-alpha.5 (2024-12-02)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/justement-api/justement-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** manual updates ([#19](https://github.com/justement-api/justement-python/issues/19)) ([6fd7b59](https://github.com/justement-api/justement-python/commit/6fd7b59bde6be4107a05355e1ada82448fe3118c))
* **api:** manual updates ([#21](https://github.com/justement-api/justement-python/issues/21)) ([76947aa](https://github.com/justement-api/justement-python/commit/76947aadfeada2667328e988af3f477e33c1d8a2))

## 0.1.0-alpha.4 (2024-11-28)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/justement-api/justement-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** manual updates ([#17](https://github.com/justement-api/justement-python/issues/17)) ([852cabd](https://github.com/justement-api/justement-python/commit/852cabdd488a51b44a597f7a9347fc3c78df1ff5))


### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#16](https://github.com/justement-api/justement-python/issues/16)) ([5b8c63c](https://github.com/justement-api/justement-python/commit/5b8c63c61910b9381e7065b66c6ae54ea1c504d0))


### Chores

* **internal:** exclude mypy from running on tests ([#14](https://github.com/justement-api/justement-python/issues/14)) ([454706d](https://github.com/justement-api/justement-python/commit/454706d5dfa3ece84f710214037706e2596ee01d))

## 0.1.0-alpha.3 (2024-11-27)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/justement-api/justement-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** manual updates ([#11](https://github.com/justement-api/justement-python/issues/11)) ([3b66f96](https://github.com/justement-api/justement-python/commit/3b66f966ad26bfc58548aabd10136eb31f7e12e0))

## 0.1.0-alpha.2 (2024-11-27)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/justement-api/justement-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** manual updates ([#9](https://github.com/justement-api/justement-python/issues/9)) ([634fa4e](https://github.com/justement-api/justement-python/commit/634fa4e9a141491d2e89472547c27b87a64d6742))


### Chores

* update SDK settings ([#7](https://github.com/justement-api/justement-python/issues/7)) ([b3a2bd7](https://github.com/justement-api/justement-python/commit/b3a2bd7be5475f61c94713809ebc5e608ed9c1cc))

## 0.1.0-alpha.1 (2024-11-26)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/justement-api/justement-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** manual updates ([#4](https://github.com/justement-api/justement-python/issues/4)) ([e209aa2](https://github.com/justement-api/justement-python/commit/e209aa2034c220add02fee82f6e6c1944ba72125))
* **api:** manual updates ([#5](https://github.com/justement-api/justement-python/issues/5)) ([2fa3789](https://github.com/justement-api/justement-python/commit/2fa3789cea61f6ae549e8a2ca9143c1daec44f3a))


### Chores

* go live ([#1](https://github.com/justement-api/justement-python/issues/1)) ([55a96ed](https://github.com/justement-api/justement-python/commit/55a96ed6932f663ce848532f726cd3cea1e0fd94))
* update SDK settings ([#3](https://github.com/justement-api/justement-python/issues/3)) ([e164af1](https://github.com/justement-api/justement-python/commit/e164af15a3d939c7f033e26203ec4c21e151066a))
